@@ -1073,7 +1073,7 @@ def plot_single_def(plot,
             raise Exception('Define axis label!')
     elif plot == 'paretoplot':
         if x is not None and y is not None:
-            if ((is_object_dtype(data[x]) == True) or (is_object_dtype(type(data[x][first_valid_index(data)])) == True) or (is_categorical_dtype(data[x]) == True) or (is_categorical_dtype(type(data[x][first_valid_index(data)])) == True)) and ((is_numeric_dtype(data[y]) == True) or (is_numeric_dtype(type(data[y][first_valid_index(data)])) == True)):
+            if ((is_object_dtype(data[x]) == True) or (is_object_dtype(type(data[x][first_valid_index(data[x])])) == True) or (is_categorical_dtype(data[x]) == True) or (is_categorical_dtype(type(data[x][first_valid_index(data[x])])) == True)) and ((is_numeric_dtype(data[y]) == True) or (is_numeric_dtype(type(data[y][first_valid_index(data[y])])) == True)):
                 data_pareto_x, idx, counts = numpy.unique(data[x], return_inverse=True, return_counts=True)
                 data_bin_y = numpy.bincount(idx, weights=data[y])
                 data_pareto_y = data_bin_y / counts
@@ -1147,7 +1147,7 @@ def plot_single_def(plot,
                 ax2.grid(False)
                 ax2.set_ylabel('Cumulative Percentage')
                 ax.get_shared_x_axes().get_siblings(ax)[0].set_ylim([0,110])
-            elif ((is_numeric_dtype(data[x]) == True) or (is_numeric_dtype(type(data[x][first_valid_index(data)])) == True)) and ((is_object_dtype(data[y]) == True) or (is_object_dtype(type(data[y][first_valid_index(data)])) == True) or (is_categorical_dtype(data[y]) == True) or (is_categorical_dtype(type(data[y][first_valid_index(data)])) == True)):
+            elif ((is_numeric_dtype(data[x]) == True) or (is_numeric_dtype(type(data[x][first_valid_index(data[x])])) == True)) and ((is_object_dtype(data[y]) == True) or (is_object_dtype(type(data[y][first_valid_index(data[y])])) == True) or (is_categorical_dtype(data[y]) == True) or (is_categorical_dtype(type(data[y][first_valid_index(data[y])])) == True)):
                 data_pareto_y, idx, counts = numpy.unique(data[y], return_inverse=True, return_counts=True)
                 data_bin_x = numpy.bincount(idx, weights=data[x])
                 data_pareto_x = data_bin_x / counts
